import sys
import argparse
from lair.project_generator import ProjectGenerator


def main(args=sys.argv[1:]):
    parser = argparse.ArgumentParser(description='Service Example')
    parser.add_argument('--project-name', help='Name of the project',
                        type=str, default=None, required=True)
    parser.add_argument('--dependencies',
                        help='Dependencies (comma separated list)',
                        type=str, default="flask,konfig", required=False)
    args = parser.parse_args(args=args)
    args.dependencies = [x for x in args.dependencies.split(',') if x != '']

    app = ProjectGenerator()
    app.set('project-name', args.project_name)
    app.set('dependencies', args.dependencies)

    try:
        app.initialize()
    except FileExistsError as e:
        print("!!!", e)
        sys.exit(1)
    app.create()



import os
from pyfakefs.fake_filesystem_unittest import TestCase
from lair.run import main
import lair


class TestRun(TestCase):
    def setUp(self):
        # We need all the template files
        # and now, I don't know better solution for that
        real_template_dir = os.path.join(
            os.path.dirname(lair.__file__),
            'templates')

        self.setUpPyfakefs()
        self.fs.add_real_directory(real_template_dir)

    def test_no_args(self):
        with self.assertRaises(SystemExit) as cm:
            main()

        self.assertEqual(cm.exception.code, 2)

    def test_project_name(self):
        main(['--project-name=test-project'])

        self.assertTrue(os.path.isdir('test-project'))
        self.assertTrue(os.path.isfile('test-project/requirements.txt'))

        with open('test-project/requirements.txt', 'r') as f:
            self.assertEqual(f.read(), 'flask\nkonfig\n')

    def test_project_name_rerun(self):
        main(['--project-name=test-project'])

        self.assertTrue(os.path.isdir('test-project'))
        self.assertTrue(os.path.isfile('test-project/requirements.txt'))

        with open('test-project/requirements.txt', 'r') as f:
            self.assertEqual(f.read(), 'flask\nkonfig\n')

        with self.assertRaises(SystemExit) as cm:
            main(['--project-name=test-project'])

        self.assertEqual(cm.exception.code, 1)

    def test_dependencies(self):
        main(['--project-name=test-project', '--dependencies=random,something'])

        self.assertTrue(os.path.isdir('test-project'))
        self.assertTrue(os.path.isfile('test-project/requirements.txt'))

        with open('test-project/requirements.txt') as f:
            self.assertEqual(f.read(), 'random\nsomething\n')
